@@ -19,6 +19,7 @@ type FixturesCmd struct {
 
 	stripeAccount string
 	apiVersion    string
+	apiBaseURL    string
 	skip          []string
 	override      []string
 	add           []string
@@ -45,6 +46,10 @@ func newFixturesCmd(cfg *config.Config) *FixturesCmd {
 	fixturesCmd.Cmd.Flags().StringArrayVar(&fixturesCmd.remove, "remove", []string{}, "Remove parameters from the fixture")
 	fixturesCmd.Cmd.Flags().StringVar(&fixturesCmd.apiVersion, "api-version", "", "Specify API version in the fixture")
 
+	// Hidden configuration flags, useful for dev/debugging
+	fixturesCmd.Cmd.Flags().StringVar(&fixturesCmd.apiBaseURL, "api-base", stripe.DefaultAPIBaseURL, "Sets the API base URL")
+	fixturesCmd.Cmd.Flags().MarkHidden("api-base") // #nosec G104
+
 	return fixturesCmd
 }
 
@@ -64,7 +69,7 @@ func (fc *FixturesCmd) runFixturesCmd(cmd *cobra.Command, args []string) error {
 		afero.NewOsFs(),
 		apiKey,
 		fc.stripeAccount,
-		stripe.DefaultAPIBaseURL,
+		fc.apiBaseURL,
 		args[0],
 		fc.skip,
 		fc.override,
